@@ -1,3 +1,7 @@
+# SPDX-FileCopyrightText: 2020 2020
+#
+# SPDX-License-Identifier: Apache-2.0
+
 """
 Validators for Splunk configuration.
 """
@@ -13,21 +17,21 @@ from inspect import isfunction
 
 
 __all__ = [
-    'Validator',
-    'ValidationError',
-    'AnyOf',
-    'AllOf',
-    'RequiresIf',
-    'UserDefined',
-    'Enum',
-    'Number',
-    'String',
-    'Pattern',
-    'Host',
-    'Port',
-    'Datetime',
-    'Email',
-    'JsonString',
+    "Validator",
+    "ValidationError",
+    "AnyOf",
+    "AllOf",
+    "RequiresIf",
+    "UserDefined",
+    "Enum",
+    "Number",
+    "String",
+    "Pattern",
+    "Host",
+    "Port",
+    "Datetime",
+    "Email",
+    "JsonString",
 ]
 basestring = str if sys.version_info[0] == 3 else basestring
 
@@ -51,9 +55,7 @@ class Validator(object):
         :return If the value is invalid, return True.
             Or return False.
         """
-        raise NotImplementedError(
-            'Function "validate" needs to be implemented.'
-        )
+        raise NotImplementedError('Function "validate" needs to be implemented.')
 
     @property
     def msg(self):
@@ -62,7 +64,7 @@ class Validator(object):
 
         :return:
         """
-        return self._msgs[0] if self._msgs else 'Invalid input value'
+        return self._msgs[0] if self._msgs else "Invalid input value"
 
     def put_msg(self, msg, high_priority=False):
         """
@@ -82,6 +84,7 @@ class ValidationFailed(Exception):
     """
     Validation error.
     """
+
     pass
 
 
@@ -108,7 +111,8 @@ class AnyOf(Validator):
                 return True
         else:
             self.put_msg(
-                'At least one of the following errors need to be fixed: %s' % json.dumps(msgs)
+                "At least one of the following errors need to be fixed: %s"
+                % json.dumps(msgs)
             )
             return False
 
@@ -134,7 +138,7 @@ class AllOf(Validator):
                 msgs.append(validator.msg)
         if msgs:
             self.put_msg(
-                'All of the following errors need to be fixed: %s' % json.dumps(msgs)
+                "All of the following errors need to be fixed: %s" % json.dumps(msgs)
             )
             return False
         return True
@@ -156,22 +160,24 @@ class RequiresIf(Validator):
             2. A function takes value & data as parameters and
                returns a boolean value
         """
-        assert isinstance(fields, (list, set, tuple)), \
-            'Argument "fields" should be list, set or tuple'
+        assert isinstance(
+            fields, (list, set, tuple)
+        ), 'Argument "fields" should be list, set or tuple'
         super(RequiresIf, self).__init__()
         self.fields = fields
         self.condition = condition
 
     @classmethod
     def _is_empty(cls, value):
-        return value is None or value == ''
+        return value is None or value == ""
 
     def validate(self, value, data):
         if self.condition is None and not self._is_empty(value):
             need_validate = True
         else:
-            assert isfunction(self.condition), \
-                'Condition should be a function for RequiresIf validator'
+            assert isfunction(
+                self.condition
+            ), "Condition should be a function for RequiresIf validator"
             need_validate = self.condition(value, data)
         if not need_validate:
             return True
@@ -179,12 +185,10 @@ class RequiresIf(Validator):
         fields = []
         for field in self.fields:
             val = data.get(field)
-            if val is None or val == '':
+            if val is None or val == "":
                 fields.append(field)
         if fields:
-            self.put_msg(
-                'For given input, fields are required: %s' % ', '.join(fields)
-            )
+            self.put_msg("For given input, fields are required: %s" % ", ".join(fields))
             return False
         return True
 
@@ -219,12 +223,7 @@ class UserDefined(Validator):
 
     def validate(self, value, data):
         try:
-            self._validator(
-                value,
-                data,
-                *self._args,
-                **self._kwargs
-            )
+            self._validator(value, data, *self._args, **self._kwargs)
         except ValidationFailed as exc:
             self.put_msg(str(exc))
             return False
@@ -248,9 +247,7 @@ class Enum(Validator):
         except TypeError:
             self._values = list(values)
 
-        self.put_msg(
-            'Value should be in %s' % json.dumps(list(self._values))
-        )
+        self.put_msg("Value should be in %s" % json.dumps(list(self._values)))
 
     def validate(self, value, data):
         return value in self._values
@@ -271,22 +268,25 @@ class Number(Validator):
         :param max_val: if not None, it requires value < max_val
         :param is_int: the value should be integer or not
         """
-        def check(val):
-            try:
-                return val is None or isinstance(val, (int, long, float))
-            except NameError:
-                return val is None or isinstance(val, (int, float))
-        assert check(min_val) and check(max_val), \
-            '%(min_val)s & %(max_val)s should be numbers' % {
-                'min_val': min_val,
-                'max_val': max_val
-            }
+
+        assert self._check(min_val) and self._check(
+            max_val
+        ), "%(min_val)s & %(max_val)s should be numbers" % {
+            "min_val": min_val,
+            "max_val": max_val,
+        }
 
         super(Number, self).__init__()
         self._min_val = min_val
         self._max_val = max_val
         self._is_int = is_int
 
+    def _check(self, val):
+        try:
+            return val is None or isinstance(val, (int, long, float))
+        except NameError:
+            return val is None or isinstance(val, (int, float))
+
     def validate(self, value, data):
         try:
             try:
@@ -295,24 +295,25 @@ class Number(Validator):
                 value = int(value) if self._is_int else float(value)
         except ValueError:
             self.put_msg(
-                'Invalid format for %s value' % ('integer' if self._is_int else 'numeric')
+                "Invalid format for %s value"
+                % ("integer" if self._is_int else "numeric")
             )
             return False
 
         msg = None
         if not self._min_val and self._max_val and value > self._max_val:
-            msg = 'Value should be smaller than %(max_val)s' % {
-                'max_val': self._max_val
+            msg = "Value should be smaller than %(max_val)s" % {
+                "max_val": self._max_val
             }
         elif not self._max_val and self._min_val and value < self._min_val:
-            msg = 'Value should be no smaller than %(min_val)s' % {
-                'min_val': self._min_val
+            msg = "Value should be no smaller than %(min_val)s" % {
+                "min_val": self._min_val
             }
         elif self._min_val and self._max_val:
             if value < self._min_val or value > self._max_val:
-                msg = 'Value should be between %(min_val)s and %(max_val)s' % {
-                    'min_val': self._min_val,
-                    'max_val': self._max_val
+                msg = "Value should be between %(min_val)s and %(max_val)s" % {
+                    "min_val": self._min_val,
+                    "max_val": self._max_val,
                 }
         if msg is not None:
             self.put_msg(msg)
@@ -336,44 +337,45 @@ class String(Validator):
             it should be longer than ``max_len``
         """
 
-        def check(val):
-            if val is None:
-                return True
-            try:
-                return isinstance(val, (int, long)) and val >= 0
-            except NameError:
-                return isinstance(val, (int)) and val >= 0
-
-        assert check(min_len) and check(max_len), \
-            '%(min_len)s & %(max_len)s should be numbers' % {
-                'min_len': min_len,
-                'max_len': max_len
-            }
+        assert self._check(min_len) and self._check(
+            max_len
+        ), "%(min_len)s & %(max_len)s should be numbers" % {
+            "min_len": min_len,
+            "max_len": max_len,
+        }
 
         super(String, self).__init__()
         self._min_len, self._max_len = min_len, max_len
 
+    def _check(self, val):
+        if val is None:
+            return True
+        try:
+            return isinstance(val, (int, long)) and val >= 0
+        except NameError:
+            return isinstance(val, (int)) and val >= 0
+
     def validate(self, value, data):
         if not isinstance(value, basestring):
-            self.put_msg('Input value should be string')
+            self.put_msg("Input value should be string")
             return False
 
         str_len = len(value)
         msg = None
 
         if not self._min_len and self._max_len and str_len > self._max_len:
-            msg = 'String should be shorter than %(max_len)s' % {
-                'max_len': self._max_len
+            msg = "String should be shorter than %(max_len)s" % {
+                "max_len": self._max_len
             }
         elif self._min_len and not self._max_len and str_len < self._min_len:
-            msg = 'String should be no shorter than %(min_len)s' % {
-                'min_len': self._min_len
+            msg = "String should be no shorter than %(min_len)s" % {
+                "min_len": self._min_len
             }
         elif self._min_len and self._max_len:
             if str_len < self._min_len or str_len > self._max_len:
-                msg = 'String length should be between %(min_len)s and %(max_len)s' % {
-                    'min_len': self._min_len,
-                    'max_len': self._max_len
+                msg = "String length should be between %(min_len)s and %(max_len)s" % {
+                    "min_len": self._min_len,
+                    "max_len": self._max_len,
                 }
         if msg is not None:
             self.put_msg(msg)
@@ -385,6 +387,7 @@ class Datetime(Validator):
     """
     Date time validation.
     """
+
     def __init__(self, datetime_format):
         """
 
@@ -396,6 +399,7 @@ class Datetime(Validator):
 
     def validate(self, value, data):
         import datetime
+
         try:
             datetime.datetime.strptime(value, self._format)
         except ValueError as exc:
@@ -420,7 +424,7 @@ class Pattern(Validator):
         """
         super(Pattern, self).__init__()
         self._regexp = re.compile(regex, flags=flags)
-        self.put_msg('Not matching the pattern: %s' % regex)
+        self.put_msg("Not matching the pattern: %s" % regex)
 
     def validate(self, value, data):
         return self._regexp.match(value) and True or False
@@ -430,19 +434,21 @@ class Host(Pattern):
     """
     A validator that accepts strings that represent network hostname.
     """
+
     def __init__(self):
         regexp = (
-            r'^(([a-zA-Z0-9]|[a-zA-Z0-9][a-zA-Z0-9\-]*[a-zA-Z0-9])\.)*'
-            r'([A-Za-z0-9]|[A-Za-z0-9][A-Za-z0-9\-]*[A-Za-z0-9])$'
+            r"^(([a-zA-Z0-9]|[a-zA-Z0-9][a-zA-Z0-9\-]*[a-zA-Z0-9])\.)*"
+            r"([A-Za-z0-9]|[A-Za-z0-9][A-Za-z0-9\-]*[A-Za-z0-9])$"
         )
         super(Host, self).__init__(regexp, flags=re.I)
-        self.put_msg('Invalid hostname', high_priority=True)
+        self.put_msg("Invalid hostname", high_priority=True)
 
 
 class Port(Number):
     """
     Port number.
     """
+
     def __init__(self):
         super(Port, self).__init__(
             min_val=0,
@@ -450,7 +456,7 @@ class Port(Number):
             is_int=True,
         )
         self.put_msg(
-            'Invalid port number, it should be a integer between 0 and 65535',
+            "Invalid port number, it should be a integer between 0 and 65535",
             high_priority=True,
         )
 
@@ -462,11 +468,11 @@ class Email(Pattern):
 
     def __init__(self):
         regexp = (
-            r'^[A-Z0-9][A-Z0-9._%+-]{0,63}@'
-            r'(?:[A-Z0-9](?:[A-Z0-9-]{0,62}[A-Z0-9])?\.){1,8}[A-Z]{2,63}$'
+            r"^[A-Z0-9][A-Z0-9._%+-]{0,63}@"
+            r"(?:[A-Z0-9](?:[A-Z0-9-]{0,62}[A-Z0-9])?\.){1,8}[A-Z]{2,63}$"
         )
         super(Email, self).__init__(regexp, flags=re.I)
-        self.put_msg('Invalid email address', high_priority=True)
+        self.put_msg("Invalid email address", high_priority=True)
 
 
 class JsonString(Validator):
@@ -478,6 +484,6 @@ class JsonString(Validator):
         try:
             json.loads(value)
         except ValueError:
-            self.put_msg('Invalid JSON string')
+            self.put_msg("Invalid JSON string")
             return False
         return True
